@@ -11,7 +11,7 @@ import transfers
 import prefs
 import util
 import notifications
-from util import OpStatus, OpCommand, TransferDirection
+from util import OpStatus, OpCommand, TransferDirection, ReceiveError
 
 _ = gettext.gettext
 
@@ -81,6 +81,8 @@ class CommonOp(GObject.Object):
             self.error_msg = e.message
         elif isinstance(e, grpc.RpcError):
             self.error_msg = e.details()
+        elif isinstance(e, ReceiveError):
+            self.error_msg = str(e)
         else:
             self.error_msg = str(e)
 
@@ -197,9 +199,10 @@ class ReceiveOp(CommonOp):
         self.have_space = False
         self.existing = False
 
-        # This is set when a transfer starts - it's a grpc.Future that we can cancel() if the user
-        # wants the transfer to stop.
+        # This will be a <_Rendezvous object of in-flight RPC> if no compression is used, and a
+        # SteamResponseWrapper (interceptors.py) if it is.
         self.file_iterator = None
+
         self.current_progress_report = None
         # These are the first-level base names (no path, just the filename) that we'll send to the server
         # to check for pre-existence.  We know that if these files/folders don't exist, none of their children
@@ -211,6 +214,8 @@ class ReceiveOp(CommonOp):
 
         if status == OpStatus.FINISHED:
             notifications.TransferCompleteNotification(self, sender=False)
+        elif status == OpStatus.FINISHED_WARNING:
+            notifications.TransferCompleteNotification(self, sender=False, warn=True)
         elif status in (OpStatus.FAILED_UNRECOVERABLE, OpStatus.FAILED):
             notifications.TransferFailedNotification(self, sender=False)
          # We only care if the other remote cancelled.  If we did it, we don't need a notification.
